@@ -207,7 +207,7 @@ int pth_select_ev(int nfd, fd_set *rfds, fd_set *wfds,
 
     /* suspend current thread until one fd is ready or the timeout occurred */
     ev = ev_select = pth_event(PTH_EVENT_SELECT|PTH_MODE_STATIC, 
-                               &ev_key_select, &rc, nfd, rfds, wfds, wfds);
+                               &ev_key_select, &rc, nfd, rfds, wfds, efds);
     ev_timeout = NULL;
     if (timeout != NULL) {
         ev_timeout = pth_event(PTH_EVENT_TIME|PTH_MODE_STATIC, &ev_key_timeout, 
