@@ -170,13 +170,13 @@ pth_t pth_spawn(pth_attr_t attr, void *(*func)(void*), void *arg)
         func = NULL;
 
     /* allocate a new thread control block */
-    stacksize = (attr == PTH_ATTR_NULL ? 32*16384 : attr->a_stacksize);
-    stackaddr = (attr == PTH_ATTR_NULL ? NULL : attr->a_stackaddr);
+    stacksize = (attr == PTH_ATTR_DEFAULT ? 32*16384 : attr->a_stacksize);
+    stackaddr = (attr == PTH_ATTR_DEFAULT ? NULL : attr->a_stackaddr);
     if ((t = pth_tcb_alloc(stacksize, stackaddr)) == NULL)
         return_errno(NULL, ENOMEM);
 
     /* configure remaining attributes */
-    if (attr != PTH_ATTR_NULL) {
+    if (attr != PTH_ATTR_DEFAULT) {
         /* overtake fields from the attribute structure */
         t->prio        = attr->a_prio;
         t->joinable    = attr->a_joinable;
