@@ -219,11 +219,14 @@ intern int pth_mctx_set(
 #if defined(HAVE_SIGALTSTACK)
 #if defined(HAVE_STACK_T)
     stack_t ss;
+    stack_t oss;
 #else
     struct sigaltstack ss;
+    struct sigaltstack oss;
 #endif
 #elif defined(HAVE_SIGSTACK)
     struct sigstack ss;
+    struct sigstack oss;
 #endif
     sigset_t osigs;
     sigset_t sigs;
@@ -263,12 +266,12 @@ intern int pth_mctx_set(
     ss.ss_sp    = sk_addr_lo; 
     ss.ss_size  = sk_addr_hi - sk_addr_lo;
     ss.ss_flags = 0;
-    if (sigaltstack(&ss, NULL) < 0)
+    if (sigaltstack(&ss, &oss) < 0)
         return FALSE;
 #elif defined(HAVE_SIGSTACK)
     ss.ss_sp = (PTH_STACKSGROWDOWN ? sk_addr_hi : sk_addr_lo);
     ss.ss_onstack = 0;
-    if (sigstack(&ss, NULL) < 0)
+    if (sigstack(&ss, &oss) < 0)
         return FALSE;
 #endif
 
@@ -306,8 +309,9 @@ intern int pth_mctx_set(
     sigaltstack(NULL, &ss);
     if (!(ss.ss_flags & SS_DISABLE)) 
         return_errno(FALSE, EIO);
+    sigaltstack(&oss, NULL);
 #elif defined(HAVE_SIGSTACK)
-    if (sigstack(&ss, NULL))
+    if (sigstack(&oss, NULL))
         return FALSE;
 #endif
 
