@@ -32,8 +32,6 @@ int pth_mutex_init(pth_mutex_t *mutex)
 {
     if (mutex == NULL)
         return_errno(FALSE, EINVAL);
-    if (mutex->mx_state & PTH_MUTEX_LOCKED)
-        return_errno(FALSE, EBUSY);
     pth_ring_init(NULL, &mutex->mx_node);
     mutex->mx_state = PTH_MUTEX_INITIALIZED;
     mutex->mx_owner = NULL;
@@ -74,7 +72,7 @@ int pth_mutex_acquire(pth_mutex_t *mutex, int try, pth_event_t ev_extra)
 
     /* should we just try? */
     if (try)
-        return_errno(FALSE, EAGAIN); 
+        return_errno(FALSE, EBUSY); 
 
     /* else wait for mutex to become unlocked.. */
     pth_debug1("pth_mutex_acquire: wait until mutex is unlocked"); 
