@@ -24,6 +24,12 @@
 
 #include "pth_p.h"
 
+/* calculate numerical mimimum */
+#if cpp
+#define pth_util_min(a,b) \
+        ((a) > (b) ? (b) : (a))
+#endif
+
 /* delete a pending signal */
 static void pth_util_sigdelete_sighandler(int _sig)
 {
