@@ -654,9 +654,8 @@ int pthread_mutex_destroy(pthread_mutex_t *mutex)
 {
     if (mutex == NULL)
         return_errno(EINVAL, EINVAL);
-    if (*mutex == PTHREAD_MUTEX_INITIALIZER)
-        return OK;
     free(*mutex);
+    *mutex = NULL;
     return OK;
 }
 
@@ -778,9 +777,8 @@ int pthread_rwlock_destroy(pthread_rwlock_t *rwlock)
 {
     if (rwlock == NULL)
         return_errno(EINVAL, EINVAL);
-    if (*rwlock == PTHREAD_RWLOCK_INITIALIZER)
-        return OK;
     free(*rwlock);
+    *rwlock = NULL;
     return OK;
 }
 
@@ -904,9 +902,8 @@ int pthread_cond_destroy(pthread_cond_t *cond)
 {
     if (cond == NULL)
         return_errno(EINVAL, EINVAL);
-    if (*cond == PTHREAD_COND_INITIALIZER)
-        return OK;
     free(*cond);
+    *cond = NULL;
     return OK;
 }
 
